<?php

namespace StylesFactory\MegaMenu\Admin\Controller;

use XF\Admin\Controller\AbstractController;
use XF\Mvc\ParameterBag;

class Menusek extends AbstractController
{

    public function actionIndex()
    {
        $MenuMag = $this->MagazineM();
        $MenuListing = $MenuMag->MenuMnie();

        $viewParams = [
            'menus' => $MenuListing->fetch(),
        ];

        return $this->view('StylesFactory\MegaMenu:Menusek\List', 'xp_custom_menu_list', $viewParams);
    }

    protected function menuAddEd(\StylesFactory\MegaMenu\Entity\Menusek $menu)
    {
        $viewParams = [
            'menu' => $menu
        ];

        return $this->view('StylesFactory\MegaMenu:Menusek\Edit', 'xp_custom_menu_edit', $viewParams);
    }

    public function actionAdd()
    {
        $menu = $this->em()->create('StylesFactory\MegaMenu:Menusek');
        return $this->menuAddEd($menu);
    }

    public function actionEdit(ParameterBag $params)
    {
        $menu = $this->assertServiceExists($params['menu_id']);

        return $this->menuAddEd($menu);
    }

    protected function serviceSaveProcess(\StylesFactory\MegaMenu\Entity\Menusek $menu)
    {
        $form = $this->formAction();

        $input = $this->filter([
            'title' => 'str',
            'desc' => 'str',
            'icon' => 'str',
            'link' => 'str',
            'background' => 'str',
            'display_order' => 'uint'
        ]);

        $form->basicEntitySave($menu, $input);

        return $form;
    }

    public function actionSave(ParameterBag $params)
    {
        $this->assertPostOnly();

        if ($params['menu_id'])
        {
            $menu = $this->assertServiceExists($params['menu_id']);
        }
        else
        {
            $menu = $this->em()->create('StylesFactory\MegaMenu:Menusek');
        }

        $this->serviceSaveProcess($menu)->run();

        return $this->redirect($this->buildLink('mega-menu/menus'));
    }

    public function actionDelete(ParameterBag $params)
    {
        $menu = $this->assertServiceExists($params['menu_id']);

        if ($this->isPost())
        {
            $menu->delete();
            return $this->redirect($this->buildLink('mega-menu/menus'));
        }
        else
        {
            $viewParams = [
                'menu' => $menu
            ];
            return $this->view('StylesFactory\MegaMenu:Menusek\Delete', 'xp_custom_menu_delete', $viewParams);
        }
    }

    protected function assertServiceExists($id, $with = null, $phraseKey = null)
    {
        return $this->assertRecordExists('StylesFactory\MegaMenu:Menusek', $id, $with, $phraseKey);
    }

    protected function MagazineM()
    {
        return $this->repository('StylesFactory\MegaMenu:Menusek');
    }

}