<?php

namespace StylesFactory\TwitchMenu\Admin\Controller;

use XF\Admin\Controller\AbstractController;
use XF\Mvc\ParameterBag;

class Menusek extends AbstractController
{

    public function actionIndex()
    {
        $MenuMag = $this->MagazineM();
        $MenuListing = $MenuMag->MenuMnie();

        $viewParams = [
            'twitchs' => $MenuListing->fetch(),
        ];

        return $this->view('StylesFactory\TwitchMenu:Menusek\List', 'xp_twitch_menu_list', $viewParams);
    }

    protected function menuAddEd(\StylesFactory\TwitchMenu\Entity\Menusek $twitch)
    {
        $viewParams = [
            'twitch' => $twitch
        ];

        return $this->view('StylesFactory\TwitchMenu:Menusek\Edit', 'xp_twitch_menu_edit', $viewParams);
    }

    public function actionAdd()
    {
        $twitch = $this->em()->create('StylesFactory\TwitchMenu:Menusek');
        return $this->menuAddEd($twitch);
    }

    public function actionEdit(ParameterBag $params)
    {
        $twitch = $this->assertServiceExists($params['twitch_id']);

        return $this->menuAddEd($twitch);
    }

    protected function serviceSaveProcess(\StylesFactory\TwitchMenu\Entity\Menusek $twitch)
    {
        $form = $this->formAction();

        $input = $this->filter([
            'title' => 'str',
            'desc' => 'str',
            'icon' => 'str',
            'link' => 'str',
            'background' => 'str',
            'display_order' => 'uint'
        ]);

        $form->basicEntitySave($twitch, $input);

        return $form;
    }

    public function actionSave(ParameterBag $params)
    {
        $this->assertPostOnly();

        if ($params['twitch_id'])
        {
            $twitch = $this->assertServiceExists($params['twitch_id']);
        }
        else
        {
            $twitch = $this->em()->create('StylesFactory\TwitchMenu:Menusek');
        }

        $this->serviceSaveProcess($twitch)->run();

        return $this->redirect($this->buildLink('twitch-menu/twitchs'));
    }

    public function actionDelete(ParameterBag $params)
    {
        $twitch = $this->assertServiceExists($params['twitch_id']);

        if ($this->isPost())
        {
            $twitch->delete();
            return $this->redirect($this->buildLink('twitch-menu/twitchs'));
        }
        else
        {
            $viewParams = [
                'twitch' => $twitch
            ];
            return $this->view('StylesFactory\TwitchMenu:Menusek\Delete', 'xp_twitch_menu_delete', $viewParams);
        }
    }

    protected function assertServiceExists($id, $with = null, $phraseKey = null)
    {
        return $this->assertRecordExists('StylesFactory\TwitchMenu:Menusek', $id, $with, $phraseKey);
    }

    protected function MagazineM()
    {
        return $this->repository('StylesFactory\TwitchMenu:Menusek');
    }

}